@@ -10,7 +10,7 @@ import (
 	"github.com/bmf-san/ggc/v5/git"
 )
 
-// mockBranchGitClient is a mock implementation of git.Clienter for branch tests
+// mockBranchGitClient is a mock implementation focused on branch operations for tests
 type mockBranchGitClient struct {
 	getCurrentBranchCalled bool
 	currentBranch          string
@@ -19,6 +19,7 @@ type mockBranchGitClient struct {
 	listRemoteBranches     func() ([]string, error)
 	mergedBranches         []string
 	checkoutNewBranchError bool
+	ops                    *mockBranchOperations
 }
 
 func (m *mockBranchGitClient) GetCurrentBranch() (string, error) {
@@ -40,32 +41,6 @@ func (m *mockBranchGitClient) ListRemoteBranches() ([]string, error) {
 	return []string{"origin/main", "origin/feature/test"}, nil
 }
 
-// Repository Information methods
-func (m *mockBranchGitClient) GetBranchName() (string, error) { return "main", nil }
-func (m *mockBranchGitClient) GetGitStatus() (string, error)  { return "", nil }
-
-// Status Operations methods
-func (m *mockBranchGitClient) Status() (string, error)               { return "", nil }
-func (m *mockBranchGitClient) StatusShort() (string, error)          { return "", nil }
-func (m *mockBranchGitClient) StatusWithColor() (string, error)      { return "", nil }
-func (m *mockBranchGitClient) StatusShortWithColor() (string, error) { return "", nil }
-
-// Staging Operations methods
-func (m *mockBranchGitClient) Add(_ ...string) error { return nil }
-func (m *mockBranchGitClient) AddInteractive() error { return nil }
-
-// Commit Operations methods
-func (m *mockBranchGitClient) Commit(_ string) error                 { return nil }
-func (m *mockBranchGitClient) CommitAmend() error                    { return nil }
-func (m *mockBranchGitClient) CommitAmendNoEdit() error              { return nil }
-func (m *mockBranchGitClient) CommitAmendWithMessage(_ string) error { return nil }
-func (m *mockBranchGitClient) CommitAllowEmpty() error               { return nil }
-
-// Diff Operations methods
-func (m *mockBranchGitClient) Diff() (string, error)       { return "", nil }
-func (m *mockBranchGitClient) DiffStaged() (string, error) { return "", nil }
-func (m *mockBranchGitClient) DiffHead() (string, error)   { return "", nil }
-
 // Branch Operations methods
 func (m *mockBranchGitClient) CheckoutNewBranch(branchName string) error {
 	if m.checkoutNewBranchError {
@@ -88,9 +63,48 @@ func (m *mockBranchGitClient) ListMergedBranches() ([]string, error) {
 	}
 	return []string{}, nil
 }
-func (m *mockBranchGitClient) RenameBranch(_, _ string) error      { return nil }
-func (m *mockBranchGitClient) MoveBranch(_, _ string) error        { return nil }
-func (m *mockBranchGitClient) SetUpstreamBranch(_, _ string) error { return nil }
+
+// Track calls for better testing
+type mockBranchOperations struct {
+	renameBranchCalls      []struct{ old, new string }
+	moveBranchCalls        []struct{ branch, commit string }
+	setUpstreamBranchCalls []struct{ branch, upstream string }
+	renameBranchError      error
+	moveBranchError        error
+	setUpstreamError       error
+	revParseVerifyResult   bool
+}
+
+func (m *mockBranchGitClient) RenameBranch(old, new string) error {
+	if m.ops == nil {
+		m.ops = &mockBranchOperations{}
+	}
+	m.ops.renameBranchCalls = append(m.ops.renameBranchCalls, struct{ old, new string }{old, new})
+	return m.ops.renameBranchError
+}
+
+func (m *mockBranchGitClient) MoveBranch(branch, commit string) error {
+	if m.ops == nil {
+		m.ops = &mockBranchOperations{}
+	}
+	m.ops.moveBranchCalls = append(m.ops.moveBranchCalls, struct{ branch, commit string }{branch, commit})
+	return m.ops.moveBranchError
+}
+
+func (m *mockBranchGitClient) SetUpstreamBranch(branch, upstream string) error {
+	if m.ops == nil {
+		m.ops = &mockBranchOperations{}
+	}
+	m.ops.setUpstreamBranchCalls = append(m.ops.setUpstreamBranchCalls, struct{ branch, upstream string }{branch, upstream})
+	return m.ops.setUpstreamError
+}
+
+func (m *mockBranchGitClient) RevParseVerify(ref string) bool {
+	if m.ops != nil {
+		return m.ops.revParseVerifyResult
+	}
+	return true // Default to valid
+}
 func (m *mockBranchGitClient) GetBranchInfo(branch string) (*git.BranchInfo, error) {
 	// Provide simple consistent info
 	bi := &git.BranchInfo{
@@ -109,88 +123,16 @@ func (m *mockBranchGitClient) ListBranchesVerbose() ([]git.BranchInfo, error) {
 		{Name: "feature", IsCurrentBranch: false, Upstream: "origin/feature", LastCommitSHA: "89abcde", LastCommitMsg: "msg2"},
 	}, nil
 }
-func (m *mockBranchGitClient) SortBranches(_ string) ([]string, error) {
-	return []string{"a", "b"}, nil
+func (m *mockBranchGitClient) SortBranches(by string) ([]string, error) {
+	if by == "date" {
+		return []string{"feature/test", "main"}, nil
+	}
+	return []string{"feature/test", "main"}, nil
 }
 func (m *mockBranchGitClient) BranchesContaining(_ string) ([]string, error) {
 	return []string{"main", "feature"}, nil
 }
 
-// Remote Operations methods
-func (m *mockBranchGitClient) Push(_ bool) error              { return nil }
-func (m *mockBranchGitClient) Pull(_ bool) error              { return nil }
-func (m *mockBranchGitClient) Fetch(_ bool) error             { return nil }
-func (m *mockBranchGitClient) RemoteList() error              { return nil }
-func (m *mockBranchGitClient) RemoteAdd(_, _ string) error    { return nil }
-func (m *mockBranchGitClient) RemoteRemove(_ string) error    { return nil }
-func (m *mockBranchGitClient) RemoteSetURL(_, _ string) error { return nil }
-
-// Tag Operations methods
-func (m *mockBranchGitClient) TagList(_ []string) error              { return nil }
-func (m *mockBranchGitClient) TagCreate(_, _ string) error           { return nil }
-func (m *mockBranchGitClient) TagCreateAnnotated(_, _ string) error  { return nil }
-func (m *mockBranchGitClient) TagDelete(_ []string) error            { return nil }
-func (m *mockBranchGitClient) TagPush(_, _ string) error             { return nil }
-func (m *mockBranchGitClient) TagPushAll(_ string) error             { return nil }
-func (m *mockBranchGitClient) TagShow(_ string) error                { return nil }
-func (m *mockBranchGitClient) GetLatestTag() (string, error)         { return "v1.0.0", nil }
-func (m *mockBranchGitClient) TagExists(_ string) bool               { return false }
-func (m *mockBranchGitClient) GetTagCommit(_ string) (string, error) { return "abc123", nil }
-
-// Log Operations methods
-func (m *mockBranchGitClient) LogSimple() error                       { return nil }
-func (m *mockBranchGitClient) LogGraph() error                        { return nil }
-func (m *mockBranchGitClient) LogOneline(_, _ string) (string, error) { return "", nil }
-
-// Rebase Operations methods
-func (m *mockBranchGitClient) RebaseInteractive(_ int) error { return nil }
-func (m *mockBranchGitClient) GetUpstreamBranch(_ string) (string, error) {
-	return "origin/main", nil
-}
-
-// Stash Operations methods
-func (m *mockBranchGitClient) Stash() error               { return nil }
-func (m *mockBranchGitClient) StashList() (string, error) { return "", nil }
-func (m *mockBranchGitClient) StashShow(_ string) error   { return nil }
-func (m *mockBranchGitClient) StashApply(_ string) error  { return nil }
-func (m *mockBranchGitClient) StashPop(_ string) error    { return nil }
-func (m *mockBranchGitClient) StashDrop(_ string) error   { return nil }
-func (m *mockBranchGitClient) StashClear() error          { return nil }
-
-// Reset and Clean Operations methods
-func (m *mockBranchGitClient) ResetHardAndClean() error         { return nil }
-func (m *mockBranchGitClient) ResetHard(_ string) error         { return nil }
-func (m *mockBranchGitClient) CleanFiles() error                { return nil }
-func (m *mockBranchGitClient) CleanDirs() error                 { return nil }
-func (m *mockBranchGitClient) CleanDryRun() (string, error)     { return "", nil }
-func (m *mockBranchGitClient) CleanFilesForce(_ []string) error { return nil }
-
-// Utility Operations methods
-func (m *mockBranchGitClient) ListFiles() (string, error) { return "", nil }
-func (m *mockBranchGitClient) GetUpstreamBranchName(_ string) (string, error) {
-	return "origin/main", nil
-}
-func (m *mockBranchGitClient) GetAheadBehindCount(_, _ string) (string, error) {
-	return "0	0", nil
-}
-func (m *mockBranchGitClient) GetVersion() (string, error)    { return "test-version", nil }
-func (m *mockBranchGitClient) GetCommitHash() (string, error) { return "test-commit", nil }
-
-// Restore Operations methods
-func (m *mockBranchGitClient) RestoreWorkingDir(_ ...string) error           { return nil }
-func (m *mockBranchGitClient) RestoreStaged(_ ...string) error               { return nil }
-func (m *mockBranchGitClient) RestoreFromCommit(_ string, _ ...string) error { return nil }
-func (m *mockBranchGitClient) RestoreAll() error                             { return nil }
-func (m *mockBranchGitClient) RestoreAllStaged() error                       { return nil }
-
-func (m *mockBranchGitClient) RevParseVerify(string) bool { return false }
-
-// Config Operations
-func (m *mockBranchGitClient) ConfigGet(_ string) (string, error)       { return "", nil }
-func (m *mockBranchGitClient) ConfigSet(_, _ string) error              { return nil }
-func (m *mockBranchGitClient) ConfigGetGlobal(_ string) (string, error) { return "", nil }
-func (m *mockBranchGitClient) ConfigSetGlobal(_, _ string) error        { return nil }
-
 func TestBrancher_Branch_Current(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
@@ -262,7 +204,7 @@ func TestBrancher_Branch_CheckoutRemote(t *testing.T) {
 	}
 	brancher.helper.outputWriter = &buf
 
-	brancher.Branch([]string{"checkout-remote"})
+	brancher.Branch([]string{"checkout", "remote"})
 
 	output := buf.String()
 	if !strings.Contains(output, "Remote branches:") {
@@ -304,7 +246,7 @@ func TestBrancher_Branch_DeleteMerged(t *testing.T) {
 	}
 	brancher.helper.outputWriter = &buf
 
-	brancher.Branch([]string{"delete-merged"})
+	brancher.Branch([]string{"delete", "merged"})
 
 	output := buf.String()
 	if !strings.Contains(output, "Select merged local branches to delete") {
@@ -367,42 +309,6 @@ func TestBrancher_branchCheckout_Error(t *testing.T) {
 	}
 }
 
-func TestBrancher_branchCheckout_NoBranches(t *testing.T) {
-	var buf bytes.Buffer
-	mockClient := &mockBranchGitClient{}
-	// Override ListLocalBranches to return empty slice
-	mockClient.listLocalBranches = func() ([]string, error) {
-		return []string{}, nil
-	}
-	brancher := &Brancher{
-		gitClient:    mockClient,
-		outputWriter: &buf,
-	}
-	brancher.branchCheckout()
-
-	output := buf.String()
-	if !strings.Contains(output, "No local branches found.") {
-		t.Errorf("Expected no branches message, got: %s", output)
-	}
-}
-
-func TestBrancher_branchCheckout_InvalidNumber(t *testing.T) {
-	var buf bytes.Buffer
-	mockClient := &mockBranchGitClient{}
-	brancher := &Brancher{
-		gitClient:    mockClient,
-		outputWriter: &buf,
-
-		inputReader: bufio.NewReader(strings.NewReader("invalid\n")),
-	}
-	brancher.branchCheckout()
-
-	output := buf.String()
-	if !strings.Contains(output, "Invalid number.") {
-		t.Errorf("Expected invalid number message, got: %s", output)
-	}
-}
-
 func TestBrancher_branchDelete_Success(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
@@ -467,8 +373,8 @@ func TestBrancher_branchDelete_Cancel(t *testing.T) {
 	brancher.branchDelete()
 
 	output := buf.String()
-	if !strings.Contains(output, "Cancelled.") {
-		t.Error("Expected cancelled message")
+	if !strings.Contains(output, "Canceled.") {
+		t.Error("Expected canceled message")
 	}
 }
 
@@ -570,8 +476,8 @@ func TestBrancher_branchDeleteMerged_Cancel(t *testing.T) {
 	brancher.branchDeleteMerged()
 
 	output := buf.String()
-	if !strings.Contains(output, "Cancelled.") {
-		t.Error("Expected cancelled message")
+	if !strings.Contains(output, "Canceled.") {
+		t.Error("Expected canceled message")
 	}
 }
 
@@ -709,7 +615,7 @@ func TestBrancher_Branch_Create(t *testing.T) {
 		{
 			name:           "Error: Empty branch name",
 			input:          "\n",
-			expectedOutput: "Enter new branch name: Cancelled.\n",
+			expectedOutput: "Enter new branch name: Canceled.\n",
 			cmdOutput:      "",
 			cmdError:       false,
 		},
@@ -758,6 +664,8 @@ func TestBrancher_branchCreate_ExistingBranch(t *testing.T) {
 	}
 }
 
+// Consolidated boundary tests for branch checkout input to avoid repetitive single-case tests.
+// Covers various numeric/non-numeric forms and validates expected outputs for each.
 func TestBrancher_Branch_BoundaryInputValues(t *testing.T) {
 	tests := []struct {
 		name     string
@@ -937,22 +845,22 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 		{
 			name:     "Empty input",
 			input:    "\n",
-			expected: "Cancelled",
+			expected: "Canceled",
 		},
 		{
 			name:     "Whitespace only",
 			input:    "   \n",
-			expected: "Cancelled",
+			expected: "Canceled",
 		},
 		{
 			name:     "Tab characters",
 			input:    "\t\t\n",
-			expected: "Cancelled",
+			expected: "Canceled",
 		},
 		{
 			name:     "Multiple newlines",
 			input:    "\n\n\n",
-			expected: "Cancelled",
+			expected: "Canceled",
 		},
 		{
 			name:     "Very long input",
@@ -1002,6 +910,8 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 	}
 }
 
+// Consolidated boundary tests for listing/selection behavior (e.g., empty lists, long names),
+// reducing the need for separate, repetitive tests for each edge case.
 func TestBrancher_Branch_BoundaryListOperations(t *testing.T) {
 	tests := []struct {
 		name          string
