@@ -13,17 +13,17 @@ import (
 	"github.com/bmf-san/ggc/v5/git"
 )
 
-// Configureer handles config operations.
-type Configureer struct {
+// Configurer handles config operations.
+type Configurer struct {
 	outputWriter io.Writer
 	helper       *Helper
 	execCommand  func(string, ...string) *exec.Cmd
-	gitClient    git.Clienter
+	gitClient    git.ConfigOps
 }
 
-// NewConfigureer creates a new Configureer instance.
-func NewConfigureer(client git.Clienter) *Configureer {
-	return &Configureer{
+// NewConfigurer creates a new Configurer instance.
+func NewConfigurer(client git.ConfigOps) *Configurer {
+	return &Configurer{
 		outputWriter: os.Stdout,
 		helper:       NewHelper(),
 		execCommand:  exec.Command,
@@ -32,7 +32,7 @@ func NewConfigureer(client git.Clienter) *Configureer {
 }
 
 // LoadConfig executes loads the configuration.
-func (c *Configureer) LoadConfig() *config.Manager {
+func (c *Configurer) LoadConfig() *config.Manager {
 	cm := config.NewConfigManager(c.gitClient)
 	if err := cm.Load(); err != nil {
 		_, _ = fmt.Fprintf(c.outputWriter, "failed to load config: %s", err)
@@ -68,77 +68,90 @@ func formatAliasValue(commands []string) string {
 }
 
 // Config executes config command operations with the given arguments.
-func (c *Configureer) Config(args []string) {
+func (c *Configurer) Config(args []string) {
 	if len(args) == 0 {
 		c.helper.ShowConfigHelp()
 		return
 	}
+
 	switch args[0] {
 	case "list":
-		cm := c.LoadConfig()
-		configs := cm.List()
-
-		keys := make([]string, 0, len(configs))
-		for key := range configs {
-			keys = append(keys, key)
-		}
-		sort.Strings(keys)
-
-		for _, key := range keys {
-			val := configs[key]
-
-			if key == "aliases" {
-				if aliasMap, ok := val.(map[string]any); ok {
-					for aliasName, raw := range aliasMap {
-						commands, err := parseAliasValue(raw)
-						if err != nil {
-							_, _ = fmt.Fprintf(c.outputWriter, "%-30s = <invalid alias: %v>\n", "aliases."+aliasName, err)
-							continue
-						}
-						formatted := formatAliasValue(commands)
-						_, _ = fmt.Fprintf(c.outputWriter, "%-30s = %s\n", "aliases."+aliasName, formatted)
-					}
-					continue
-				}
-			}
-
-			_, _ = fmt.Fprintf(c.outputWriter, "%-30s = %s\n", key, formatValue(val))
-		}
-		return
+		c.configList()
 	case "get":
-		if len(args) < 2 {
-			_, _ = fmt.Fprintf(c.outputWriter, "must provide key to get (arg missing)\n")
-			return
-		}
-
-		cm := c.LoadConfig()
-
-		value, err := cm.Get(args[1])
-		if err != nil {
-			_, _ = fmt.Fprintf(c.outputWriter, "failed to get config value: %s", err)
-		}
-
-		_, _ = fmt.Fprintf(c.outputWriter, "%s\n", formatValue(value))
-		return
+		c.configGet(args)
 	case "set":
-		if len(args) < 3 {
-			_, _ = fmt.Fprintf(c.outputWriter, "must provide key && value to set (arg(s) missing)\n")
-			return
-		}
-
-		cm := c.LoadConfig()
-
-		value := parseValue(args[2])
-		if err := cm.Set(args[1], value); err != nil {
-			_, _ = fmt.Fprintf(c.outputWriter, "failed to set config value: %s", err)
-		}
-
-		_, _ = fmt.Fprintf(c.outputWriter, "Set %s = %s\n", args[1], formatValue(value))
-		return
+		c.configSet(args)
 	default:
 		c.helper.ShowConfigHelp()
+	}
+}
+
+// configList lists all configuration values
+func (c *Configurer) configList() {
+	cm := c.LoadConfig()
+	configs := cm.List()
+
+	keys := make([]string, 0, len(configs))
+	for key := range configs {
+		keys = append(keys, key)
+	}
+	sort.Strings(keys)
+
+	for _, key := range keys {
+		val := configs[key]
+		if key == "aliases" {
+			c.displayAliases(val)
+			continue
+		}
+		_, _ = fmt.Fprintf(c.outputWriter, "%-30s = %s\n", key, formatValue(val))
+	}
+}
+
+// displayAliases handles the special display logic for aliases
+func (c *Configurer) displayAliases(val any) {
+	if aliasMap, ok := val.(map[string]any); ok {
+		for aliasName, raw := range aliasMap {
+			commands, err := parseAliasValue(raw)
+			if err != nil {
+				_, _ = fmt.Fprintf(c.outputWriter, "%-30s = <invalid alias: %v>\n", "aliases."+aliasName, err)
+				continue
+			}
+			formatted := formatAliasValue(commands)
+			_, _ = fmt.Fprintf(c.outputWriter, "%-30s = %s\n", "aliases."+aliasName, formatted)
+		}
+	}
+}
+
+// configGet gets a configuration value
+func (c *Configurer) configGet(args []string) {
+	if len(args) < 2 {
+		_, _ = fmt.Fprintf(c.outputWriter, "must provide key to get (arg missing)\n")
 		return
 	}
+
+	cm := c.LoadConfig()
+	value, err := cm.Get(args[1])
+	if err != nil {
+		_, _ = fmt.Fprintf(c.outputWriter, "failed to get config value: %s", err)
+	}
+
+	_, _ = fmt.Fprintf(c.outputWriter, "%s\n", formatValue(value))
+}
+
+// configSet sets a configuration value
+func (c *Configurer) configSet(args []string) {
+	if len(args) < 3 {
+		_, _ = fmt.Fprintf(c.outputWriter, "must provide key && value to set (arg(s) missing)\n")
+		return
+	}
+
+	cm := c.LoadConfig()
+	value := parseValue(args[2])
+	if err := cm.Set(args[1], value); err != nil {
+		_, _ = fmt.Fprintf(c.outputWriter, "failed to set config value: %s", err)
+	}
+
+	_, _ = fmt.Fprintf(c.outputWriter, "Set %s = %s\n", args[1], formatValue(value))
 }
 
 func formatValue(value any) string {
