@@ -73,7 +73,7 @@ func TestRebaser_RebaseInteractive_Cancel(t *testing.T) {
 	r.RebaseInteractive()
 
 	output := buf.String()
-	if !strings.Contains(output, "Error: operation cancelled") {
+	if !strings.Contains(output, "Error: operation canceled") {
 		t.Errorf("expected cancellation message, got: %s", output)
 	}
 }
@@ -176,20 +176,20 @@ func TestRebaser_Rebase(t *testing.T) {
 		mockInput      string
 	}{
 		{
-			name:           "interactive rebase via -i",
-			args:           []string{"-i"},
+			name:           "interactive rebase",
+			args:           []string{"interactive"},
 			expectedOutput: "Current branch:",
 			mockInput:      "1\n",
 		},
 		{
 			name:           "no args",
 			args:           []string{},
-			expectedOutput: "Usage: ggc rebase",
+			expectedOutput: "Usage: ggc rebase [interactive | <upstream> | continue | abort | skip]",
 		},
 		{
-			name:           "invalid command",
+			name:           "invalid ref errors",
 			args:           []string{"invalid"},
-			expectedOutput: "Usage: ggc rebase",
+			expectedOutput: "Error: unknown ref",
 		},
 	}
 
@@ -197,6 +197,9 @@ func TestRebaser_Rebase(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			var buf bytes.Buffer
 			mockClient := &mockAddGitClient{}
+			if tc.name == "invalid ref errors" {
+				mockClient.RevParseVerifyFunc = func(_ string) bool { return false }
+			}
 			r := &Rebaser{
 				gitClient:    mockClient,
 				outputWriter: &buf,
@@ -215,6 +218,75 @@ func TestRebaser_Rebase(t *testing.T) {
 	}
 }
 
+func TestRebaser_Rebase_Subcommands(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockAddGitClient{}
+	r := &Rebaser{
+		gitClient:    mockClient,
+		outputWriter: &buf,
+		helper:       NewHelper(),
+		inputReader:  bufio.NewReader(strings.NewReader("")),
+	}
+	r.helper.outputWriter = &buf
+
+	// continue
+	buf.Reset()
+	mockClient.RebaseContinueCalled = false
+	r.Rebase([]string{"continue"})
+	if !mockClient.RebaseContinueCalled {
+		t.Errorf("expected RebaseContinue to be called")
+	}
+	if !strings.Contains(buf.String(), "Rebase successful") {
+		t.Errorf("expected success message, got: %s", buf.String())
+	}
+
+	// abort
+	buf.Reset()
+	mockClient.RebaseAbortCalled = false
+	r.Rebase([]string{"abort"})
+	if !mockClient.RebaseAbortCalled {
+		t.Errorf("expected RebaseAbort to be called")
+	}
+	if !strings.Contains(buf.String(), "Rebase aborted") {
+		t.Errorf("expected abort message, got: %s", buf.String())
+	}
+
+	// skip
+	buf.Reset()
+	mockClient.RebaseSkipCalled = false
+	r.Rebase([]string{"skip"})
+	if !mockClient.RebaseSkipCalled {
+		t.Errorf("expected RebaseSkip to be called")
+	}
+	if !strings.Contains(buf.String(), "Rebase successful") {
+		t.Errorf("expected success message, got: %s", buf.String())
+	}
+}
+
+func TestRebaser_Rebase_BasicOnto(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockAddGitClient{}
+	mockClient.RevParseVerifyFunc = func(ref string) bool {
+		return ref == "main" || ref == "origin/main"
+	}
+	r := &Rebaser{
+		gitClient:    mockClient,
+		outputWriter: &buf,
+		helper:       NewHelper(),
+		inputReader:  bufio.NewReader(strings.NewReader("")),
+	}
+	r.helper.outputWriter = &buf
+
+	buf.Reset()
+	r.Rebase([]string{"main"})
+	if !mockClient.RebaseCalled || mockClient.RebaseUpstream != "main" {
+		t.Errorf("expected Rebase to be called with 'main', got called=%v upstream=%q", mockClient.RebaseCalled, mockClient.RebaseUpstream)
+	}
+	if !strings.Contains(buf.String(), "Rebase successful") {
+		t.Errorf("expected success message, got: %s", buf.String())
+	}
+}
+
 func TestRebaser_Rebase_InteractiveCancel(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockAddGitClient{}
@@ -230,7 +302,7 @@ func TestRebaser_Rebase_InteractiveCancel(t *testing.T) {
 	}
 	r.helper.outputWriter = &buf
 
-	r.Rebase([]string{"-i"})
+	r.Rebase([]string{"interactive"})
 
 	output := buf.String()
 	if !strings.Contains(output, "Error: no commit history found") {
@@ -249,7 +321,7 @@ func TestRebaser_Rebase_Error(t *testing.T) {
 	}
 	r.helper.outputWriter = &buf
 
-	r.Rebase([]string{"-i"})
+	r.Rebase([]string{"interactive"})
 
 	output := buf.String()
 	if !strings.Contains(output, "Error:") {
