@@ -66,6 +66,11 @@ func (OSFileOps) Rename(oldpath, newpath string) error { return os.Rename(oldpat
 // Chmod changes file permissions
 func (OSFileOps) Chmod(name string, mode os.FileMode) error { return os.Chmod(name, mode) }
 
+// KeybindingsConfig represents a configuration section with keybindings
+type KeybindingsConfig struct {
+	Keybindings map[string]interface{} `yaml:"keybindings,omitempty"`
+}
+
 // Config represents the complete configuration structure
 type Config struct {
 	Meta struct {
@@ -86,6 +91,32 @@ type Config struct {
 		Pager bool `yaml:"pager"`
 	} `yaml:"ui"`
 
+	Interactive struct {
+		Profile string `yaml:"profile,omitempty"`
+
+		Keybindings struct {
+			DeleteWord      string `yaml:"delete_word"`
+			ClearLine       string `yaml:"clear_line"`
+			DeleteToEnd     string `yaml:"delete_to_end"`
+			MoveToBeginning string `yaml:"move_to_beginning"`
+			MoveToEnd       string `yaml:"move_to_end"`
+			MoveUp          string `yaml:"move_up"`
+			MoveDown        string `yaml:"move_down"`
+		} `yaml:"keybindings"`
+
+		Contexts struct {
+			Input   KeybindingsConfig `yaml:"input,omitempty"`
+			Results KeybindingsConfig `yaml:"results,omitempty"`
+			Search  KeybindingsConfig `yaml:"search,omitempty"`
+		} `yaml:"contexts,omitempty"`
+
+		Darwin  KeybindingsConfig `yaml:"darwin,omitempty"`
+		Linux   KeybindingsConfig `yaml:"linux,omitempty"`
+		Windows KeybindingsConfig `yaml:"windows,omitempty"`
+
+		Terminals map[string]KeybindingsConfig `yaml:"terminals,omitempty"`
+	} `yaml:"interactive"`
+
 	Behavior struct {
 		AutoPush           bool   `yaml:"auto-push"`
 		ConfirmDestructive string `yaml:"confirm-destructive"`
@@ -348,6 +379,9 @@ func (c *Config) Validate() error {
 	if err := c.validateAliases(); err != nil {
 		return err
 	}
+	if err := c.validateKeybindings(); err != nil {
+		return err
+	}
 	return nil
 }
 
@@ -945,3 +979,196 @@ func (cm *Manager) LoadConfig() {
 func (cm *Manager) GetConfig() *Config {
 	return cm.config
 }
+
+// validateKeybindings validates the keybinding configuration
+func (c *Config) validateKeybindings() error {
+	// Validate profile selection
+	if err := c.validateProfile(); err != nil {
+		return err
+	}
+
+	// Validate global keybindings
+	bindings := map[string]string{
+		"delete_word":       c.Interactive.Keybindings.DeleteWord,
+		"clear_line":        c.Interactive.Keybindings.ClearLine,
+		"delete_to_end":     c.Interactive.Keybindings.DeleteToEnd,
+		"move_to_beginning": c.Interactive.Keybindings.MoveToBeginning,
+		"move_to_end":       c.Interactive.Keybindings.MoveToEnd,
+		"move_up":           c.Interactive.Keybindings.MoveUp,
+		"move_down":         c.Interactive.Keybindings.MoveDown,
+	}
+
+	for action, keyStr := range bindings {
+		// Empty bindings are allowed (will use defaults)
+		if keyStr == "" {
+			continue
+		}
+		if err := parseKeyBinding(keyStr); err != nil {
+			return &ValidationError{
+				Field:   fmt.Sprintf("interactive.keybindings.%s", action),
+				Value:   keyStr,
+				Message: err.Error(),
+			}
+		}
+	}
+
+	// Validate context-specific keybindings
+	if err := c.validateContextKeybindings(); err != nil {
+		return err
+	}
+
+	// Validate platform-specific keybindings
+	if err := c.validatePlatformKeybindings(); err != nil {
+		return err
+	}
+
+	return nil
+}
+
+// validateProfile validates the profile selection
+func (c *Config) validateProfile() error {
+	profile := c.Interactive.Profile
+	if profile == "" {
+		return nil // Empty profile is allowed (defaults to "default")
+	}
+
+	validProfiles := map[string]bool{
+		"default":  true,
+		"emacs":    true,
+		"vi":       true,
+		"readline": true,
+	}
+
+	if !validProfiles[profile] {
+		return &ValidationError{
+			Field:   "interactive.profile",
+			Value:   profile,
+			Message: "must be one of: default, emacs, vi, readline",
+		}
+	}
+	return nil
+}
+
+// validateContextKeybindings validates context-specific keybindings
+func (c *Config) validateContextKeybindings() error {
+	contexts := map[string]map[string]interface{}{
+		"input":   c.Interactive.Contexts.Input.Keybindings,
+		"results": c.Interactive.Contexts.Results.Keybindings,
+		"search":  c.Interactive.Contexts.Search.Keybindings,
+	}
+
+	for contextName, bindings := range contexts {
+		if bindings == nil {
+			continue
+		}
+		for action, value := range bindings {
+			if err := validateKeybindingValue(fmt.Sprintf("interactive.contexts.%s.keybindings.%s", contextName, action), value); err != nil {
+				return err
+			}
+		}
+	}
+	return nil
+}
+
+// validatePlatformKeybindings validates platform and terminal specific keybindings
+func (c *Config) validatePlatformKeybindings() error {
+	platforms := map[string]map[string]interface{}{
+		"darwin":  c.Interactive.Darwin.Keybindings,
+		"linux":   c.Interactive.Linux.Keybindings,
+		"windows": c.Interactive.Windows.Keybindings,
+	}
+
+	for platformName, bindings := range platforms {
+		if bindings == nil {
+			continue
+		}
+		for action, value := range bindings {
+			if err := validateKeybindingValue(fmt.Sprintf("interactive.%s.keybindings.%s", platformName, action), value); err != nil {
+				return err
+			}
+		}
+	}
+
+	// Validate terminal-specific keybindings
+	if c.Interactive.Terminals != nil {
+		for termName, termConfig := range c.Interactive.Terminals {
+			if termConfig.Keybindings == nil {
+				continue
+			}
+			for action, value := range termConfig.Keybindings {
+				if err := validateKeybindingValue(fmt.Sprintf("interactive.terminals.%s.keybindings.%s", termName, action), value); err != nil {
+					return err
+				}
+			}
+		}
+	}
+
+	return nil
+}
+
+// validateKeybindingValue validates a keybinding value (string or array of strings)
+func validateKeybindingValue(fieldPath string, value interface{}) error {
+	switch v := value.(type) {
+	case string:
+		if v == "" {
+			return nil // Empty is allowed
+		}
+		if err := parseKeyBinding(v); err != nil {
+			return &ValidationError{
+				Field:   fieldPath,
+				Value:   v,
+				Message: err.Error(),
+			}
+		}
+	case []interface{}:
+		for i, item := range v {
+			itemStr, ok := item.(string)
+			if !ok {
+				return &ValidationError{
+					Field:   fmt.Sprintf("%s[%d]", fieldPath, i),
+					Value:   item,
+					Message: "keybinding array items must be strings",
+				}
+			}
+			if itemStr != "" {
+				if err := parseKeyBinding(itemStr); err != nil {
+					return &ValidationError{
+						Field:   fmt.Sprintf("%s[%d]", fieldPath, i),
+						Value:   itemStr,
+						Message: err.Error(),
+					}
+				}
+			}
+		}
+	default:
+		return &ValidationError{
+			Field:   fieldPath,
+			Value:   value,
+			Message: "keybinding must be a string or array of strings",
+		}
+	}
+	return nil
+}
+
+// parseKeyBinding validates key binding strings.
+// This simple validation is implemented here to avoid a circular import:
+// importing the full keybinding parser from the 'cmd' (interactive UI) package
+// would cause a circular dependency, since that package depends on 'config'.
+func parseKeyBinding(keyStr string) error { //nolint:revive // parsing multiple legacy formats
+	s := strings.TrimSpace(keyStr)
+	if s == "" {
+		return fmt.Errorf("empty key binding")
+	}
+
+	// Basic validation - check for supported formats
+	sLower := strings.ToLower(s)
+
+	// Accept ctrl+<key>, ^<key>, or c-<key> formats
+	if (strings.HasPrefix(sLower, "ctrl+") && len(s) >= 6) ||
+		(strings.HasPrefix(s, "^") && len(s) == 2) ||
+		(strings.HasPrefix(sLower, "c-") && len(s) == 3) {
+		return nil
+	}
+
+	return fmt.Errorf("unsupported key binding format: %s (supported: 'ctrl+<key>', '^<key>', 'c-<key>')", keyStr)
+}
